@@ -8,6 +8,21 @@
 
 from pyuvm.s05_base_classes import uvm_object
 import logging
+import sys
+from cocotb.log import SimColourLogFormatter, SimTimeContextFilter
+from logging import DEBUG, CRITICAL, ERROR, WARNING, INFO, NOTSET, NullHandler   # noqa: F401, E501
+
+
+class PyuvmFormatter(SimColourLogFormatter):
+    def __init__(self, full_name):
+        self.full_name = full_name
+        super().__init__()
+
+    def format(self, record):
+        new_msg = f"{record.filename}({record.lineno})"
+        new_msg += f"[{self.full_name}]: " + record.msg
+        record.msg = new_msg
+        return super().format(record)
 
 
 # 6.2.1
@@ -23,15 +38,15 @@ class uvm_report_object(uvm_object):
         self.logger.setLevel(level=logging.INFO)  # Default is to print INFO
         # We are not sending log messages up the hierarchy
         self.logger.propagate = False
-        handler = logging.StreamHandler()
+        self._streaming_handler = logging.StreamHandler(sys.stdout)
+        self._streaming_handler.addFilter(SimTimeContextFilter())
         # Don't let the handler interfere with logger level
-        handler.setLevel(logging.NOTSET)
+        self._streaming_handler.setLevel(logging.NOTSET)
         # Make log messages look like UVM messages
-        formatter = logging.Formatter(
-            "%(levelname)s: %(filename)s(%(lineno)d)[" + self.get_full_name() + "]: %(message)s")  # noqa: E501
-        handler.setFormatter(formatter)
-        self.add_logging_handler(handler)
-        pass
+        self._uvm_formatter = PyuvmFormatter(self.get_full_name())
+#        self._uvm_formatter = logging.Formatter(
+#            "%(levelname)s: %(filename)s(%(lineno)d)[" + self.get_full_name() + "]: %(message)s")  # noqa: E501
+        self.add_logging_handler(self._streaming_handler)
 
     def set_logging_level(self, logging_level):
         """ Sets the logger level """
@@ -41,6 +56,9 @@ class uvm_report_object(uvm_object):
         """ Adds a handler """
         assert isinstance(handler, logging.Handler), \
             f"You must pass a logging.Handler not {type(handler)}"
+        if handler.formatter is None:
+            handler.addFilter(SimTimeContextFilter())
+            handler.setFormatter(self._uvm_formatter)
         self.logger.addHandler(handler)
 
     def remove_logging_handler(self, handler):
@@ -49,9 +67,9 @@ class uvm_report_object(uvm_object):
             f"You must pass a logging.Handler not {type(handler)}"
         self.logger.removeHandler(handler)
 
-    def set_formatter_on_handlers(self, formatter):
-        """ Set an identical formatter on all handlers """
-        assert isinstance(formatter, logging.Formatter), \
-            f"You must pass a logging.Formatter not {type(formatter)}"
-        for handler in self.logger.handlers:
-            handler.setFormatter(formatter)
+    def remove_streaming_handler(self):
+        self.logger.removeHandler(self._streaming_handler)
+
+    def disable_logging(self):
+        self.remove_streaming_handler()
+        self.add_logging_handler(NullHandler())
